import { MatrixClient } from "../MatrixClient";
/**
 * Unstable creation options for an MSC1772 Space.
 *
 * Caution: implementation of this class may change without notice or warning, including
 * removal of the class.
 *
 * @deprecated Not intended for use until MSC1772 is ready, at which point the class is replaced.
 * @category Unstable APIs
 */
export interface MSC1772SpaceCreateOptions {
    name: string;
    topic?: string;
    isPublic: boolean;
    localpart: string;
}
/**
 * Unstable implementation of MSC1772 Spaces.
 *
 * Caution: implementation of this class may change without notice or warning, including
 * removal of the class.
 *
 * @deprecated Not intended for use until MSC1772 is ready, at which point the class is replaced.
 * @category Unstable APIs
 */
export declare class MSC1772Space {
    readonly roomId: string;
    readonly client: MatrixClient;
    constructor(roomId: string, client: MatrixClient);
    /**
     * Creates a new child space.
     * @param {MSC1772SpaceCreateOptions} opts The options for the new space.
     * @returns {Promise<MSC1772Space>} Resolves to the created space.
     */
    createChildSpace(opts: MSC1772SpaceCreateOptions): Promise<MSC1772Space>;
    /**
     * Adds a child space to the space. Must be joined to both spaces.
     * @param {MSC1772Space} space The space to add.
     * @returns {Promise<MSC1772Space>} Resolves when complete.
     */
    addChildSpace(space: MSC1772Space): Promise<void>;
    /**
     * Removes a child space from the space. Must be joined to the current space (not needed for child space).
     * @param {MSC1772Space} space The space to remove.
     * @returns {Promise<MSC1772Space>} Resolves when complete.
     */
    removeChildSpace(space: MSC1772Space): Promise<void>;
    /**
     * Adds a child room to the space. Must be joined to both the room and the space.
     * @param {string} roomId The room ID to add.
     * @returns {Promise<void>} Resolves when complete.
     */
    addChildRoom(roomId: string): Promise<void>;
    /**
     * Removes a child room from the space. Must be joined to the current space (not needed for child room).
     * @param {string} roomId The room ID to remove.
     * @returns {Promise<MSC1772Space>} Resolves when complete.
     */
    removeChildRoom(roomId: string): Promise<void>;
    /**
     * Gets all the child rooms on the space. These may be spaces or other rooms.
     * @returns {Promise<MSC1772Space>} Resolves to the room IDs of the children.
     */
    getChildEntities(): Promise<string[]>;
}
