"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MSC1772Space = void 0;
const MatrixEntity_1 = require("../helpers/MatrixEntity");
/**
 * Unstable implementation of MSC1772 Spaces.
 *
 * Caution: implementation of this class may change without notice or warning, including
 * removal of the class.
 *
 * @deprecated Not intended for use until MSC1772 is ready, at which point the class is replaced.
 * @category Unstable APIs
 */
class MSC1772Space {
    constructor(roomId, client) {
        this.roomId = roomId;
        this.client = client;
    }
    /**
     * Creates a new child space.
     * @param {MSC1772SpaceCreateOptions} opts The options for the new space.
     * @returns {Promise<MSC1772Space>} Resolves to the created space.
     */
    createChildSpace(opts) {
        return __awaiter(this, void 0, void 0, function* () {
            const space = yield this.client.unstableApis.createSpace(opts);
            yield this.addChildSpace(space);
            return space;
        });
    }
    /**
     * Adds a child space to the space. Must be joined to both spaces.
     * @param {MSC1772Space} space The space to add.
     * @returns {Promise<MSC1772Space>} Resolves when complete.
     */
    addChildSpace(space) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.addChildRoom(space.roomId);
        });
    }
    /**
     * Removes a child space from the space. Must be joined to the current space (not needed for child space).
     * @param {MSC1772Space} space The space to remove.
     * @returns {Promise<MSC1772Space>} Resolves when complete.
     */
    removeChildSpace(space) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.removeChildRoom(space.roomId);
        });
    }
    /**
     * Adds a child room to the space. Must be joined to both the room and the space.
     * @param {string} roomId The room ID to add.
     * @returns {Promise<void>} Resolves when complete.
     */
    addChildRoom(roomId) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.client.sendStateEvent(roomId, "org.matrix.msc1772.room.parent", "", {
                room_id: roomId,
                via: [new MatrixEntity_1.UserID(yield this.client.getUserId()).domain],
            });
            yield this.client.sendStateEvent(this.roomId, "org.matrix.msc1772.space.child", roomId, {
                present: true,
                via: [new MatrixEntity_1.UserID(yield this.client.getUserId()).domain],
            });
        });
    }
    /**
     * Removes a child room from the space. Must be joined to the current space (not needed for child room).
     * @param {string} roomId The room ID to remove.
     * @returns {Promise<MSC1772Space>} Resolves when complete.
     */
    removeChildRoom(roomId) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.client.sendStateEvent(this.roomId, "org.matrix.msc1772.space.child", roomId, {
                present: false,
                via: [new MatrixEntity_1.UserID(yield this.client.getUserId()).domain],
            });
        });
    }
    /**
     * Gets all the child rooms on the space. These may be spaces or other rooms.
     * @returns {Promise<MSC1772Space>} Resolves to the room IDs of the children.
     */
    getChildEntities() {
        return __awaiter(this, void 0, void 0, function* () {
            const roomState = yield this.client.getRoomState(this.roomId);
            return roomState
                .filter(s => s.type === "org.matrix.msc1772.space.child")
                .filter(s => { var _a; return ((_a = s.content) === null || _a === void 0 ? void 0 : _a.present) === true; })
                .map(s => s.state_key);
        });
    }
}
exports.MSC1772Space = MSC1772Space;
